pub struct SearchCodeInput {Show 14 fields
pub query: String,
pub mode: SearchMode,
pub path: Option<String>,
pub include: Vec<String>,
pub exclude: Vec<String>,
pub types: Vec<String>,
pub type_not: Vec<String>,
pub case_mode: SearchCase,
pub word: bool,
pub whole_line: bool,
pub hidden: bool,
pub respect_ignore: bool,
pub follow: bool,
pub limit: Option<usize>,
}Fields
query: Stringmode: SearchModepath: Option<String>include: Vec<String>exclude: Vec<String>types: Vec<String>type_not: Vec<String>case_mode: SearchCaseword: boolwhole_line: boolrespect_ignore: boolfollow: boollimit: Option<usize>Trait Implementations
Sourceimpl Clone for SearchCodeInput
impl Clone for SearchCodeInput
Sourcefn clone(&self) -> SearchCodeInput
fn clone(&self) -> SearchCodeInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SearchCodeInput
impl Debug for SearchCodeInput
Sourceimpl Default for SearchCodeInput
impl Default for SearchCodeInput
Sourceimpl<'de> Deserialize<'de> for SearchCodeInput
impl<'de> Deserialize<'de> for SearchCodeInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SearchCodeInput
impl JsonSchema for SearchCodeInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SearchCodeInput
impl RefUnwindSafe for SearchCodeInput
impl Send for SearchCodeInput
impl Sync for SearchCodeInput
impl Unpin for SearchCodeInput
impl UnsafeUnpin for SearchCodeInput
impl UnwindSafe for SearchCodeInput