is_responsible_source

Function is_responsible_source 

pub fn is_responsible_source(
    project_root: &Path,
    params: &SourceResponsibilityInput,
) -> Result<SourceResponsibility, String>
Determines whether a path belongs to source this engine can analyze.

Errors

Returns an error if the path is invalid or escapes the project root.