pub struct JdtlsConfig;Trait Implementations
Sourceimpl LspServerConfig for JdtlsConfig
impl LspServerConfig for JdtlsConfig
Sourcefn server_name(&self) -> &'static str
fn server_name(&self) -> &'static str
Human-readable name for logging.
Sourcefn binary_name(&self) -> &'static str
fn binary_name(&self) -> &'static str
The binary name to look for on PATH (e.g. “rust-analyzer”, “pyright-langserver”).
Sourcefn language_id(&self) -> &'static str
fn language_id(&self) -> &'static str
The LSP language ID for
textDocument/didOpen (e.g. “rust”, “python”).Sourcefn cached_binary_name(&self) -> String
fn cached_binary_name(&self) -> String
Cache directory relative filename for the downloaded binary (if applicable).
Sourcefn download_url(&self) -> Option<String>
fn download_url(&self) -> Option<String>
URL to download the binary from (if PATH lookup fails and download feature enabled).
Sourcefn spawn_args(&self) -> Vec<String>
fn spawn_args(&self) -> Vec<String>
Arguments to pass to the server binary when spawning.
Sourcefn post_init_delay_secs(&self) -> u64
fn post_init_delay_secs(&self) -> u64
Seconds to sleep after initialization to let the server index.
Sourcefn setup_hints(&self) -> String
fn setup_hints(&self) -> String
Human-readable setup/installation hints for this LSP server.
Returns a description of how to install the server, for the agent to act on.
Sourcefn init_params_extra(&self, _root_uri: &str) -> Value
fn init_params_extra(&self, _root_uri: &str) -> Value
Extra initialization parameters to include in the LSP
initialize request.Auto Trait Implementations
impl Freeze for JdtlsConfig
impl RefUnwindSafe for JdtlsConfig
impl Send for JdtlsConfig
impl Sync for JdtlsConfig
impl Unpin for JdtlsConfig
impl UnsafeUnpin for JdtlsConfig
impl UnwindSafe for JdtlsConfig