edit_code_apply

Function edit_code_apply 

pub fn edit_code_apply(
    edits: &[StructuredEdit],
    project_root: &Path,
    lsp_analyzer: &Mutex<Option<Box<dyn Analyzer + Send>>>,
) -> Result<(Vec<PropagationResult>, AppliedStructuredEditSummary), String>
Applies structured edits and discovers references that need propagation review.

Errors

Returns an error when an edit is invalid or cannot be written.