Structs
- Parsed
Selector - A parsed SCOPE selector. The selector is a positioning DSL: it locates targets/ranges, but it does not encode operation semantics.
- Symbol
Selector
Enums
Functions
- parse_
selector - Parse a selector string of the form
file_path::[kind ]name. - resolve_
file - Resolve a selector’s file path against a project root, and return the absolute path along with the file extension (for language detection).